@@ -23,7 +23,9 @@ status_key_mapping = {
     'speed': 'speed',
     'shaking': 'oscillating',
     'shake_center': 'oscillating_center',
-    'shake_range': 'oscillating_range'
+    'shake_range': 'oscillating_range',
+    'lock_state': 'lock_state',
+    'door_state': 'door_state'
 }
 
 
@@ -91,10 +93,28 @@ class Curtain(Device):
     device_type_for = 'Curtain'
 
     def __init__(self, client: SwitchBotClient, id: str, **extra):
-        super().__init__(self, id, **extra)
+        super().__init__(self, client, id, **extra)
 
         self.curtain_ids: List[str] = extra.get('curtain_devices_ids')
         self.calibrated: bool = extra.get('calibrate')
         self.grouped: bool = extra.get('group')
         self.master: bool = extra.get('master')
         self.open_direction: str = extra.get('open_direction')
+
+class Lock(Device):
+    device_type_for = 'Smart Lock'
+
+    def lock(self):
+        self.command('lock')
+
+    def unlock(self):
+        self.command('unlock')
+
+    def toggle(self):
+        state = self.status()['lock_state']
+        assert state in ('unlocked', 'locked')
+
+        if state == 'unlocked':
+            self.lock()
+        else:
+            self.unlock()
\ No newline at end of file
